@@ -83,24 +83,30 @@ class MetricCollection(ModuleDict):
     Example (input as list):
         >>> import torch
         >>> from pprint import pprint
-        >>> from torchmetrics import MetricCollection, Accuracy, Precision, Recall, MeanSquaredError
+        >>> from torchmetrics import MetricCollection, MeanSquaredError
+        >>> from torchmetrics.classification import MulticlassAccuracy, MulticlassPrecision, MulticlassRecall
         >>> target = torch.tensor([0, 2, 0, 2, 0, 1, 0, 2])
         >>> preds = torch.tensor([2, 1, 2, 0, 1, 2, 2, 2])
-        >>> metrics = MetricCollection([Accuracy(),
-        ...                             Precision(num_classes=3, average='macro'),
-        ...                             Recall(num_classes=3, average='macro')])
-        >>> metrics(preds, target)
-        {'Accuracy': tensor(0.1250), 'Precision': tensor(0.0667), 'Recall': tensor(0.1111)}
+        >>> metrics = MetricCollection([MulticlassAccuracy(num_classes=3, average='micro'),
+        ...                             MulticlassPrecision(num_classes=3, average='macro'),
+        ...                             MulticlassRecall(num_classes=3, average='macro')])
+        >>> metrics(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        {'MulticlassAccuracy': tensor(0.1250),
+         'MulticlassPrecision': tensor(0.0667),
+         'MulticlassRecall': tensor(0.1111)}
 
     Example (input as arguments):
-        >>> metrics = MetricCollection(Accuracy(), Precision(num_classes=3, average='macro'),
-        ...                            Recall(num_classes=3, average='macro'))
-        >>> metrics(preds, target)
-        {'Accuracy': tensor(0.1250), 'Precision': tensor(0.0667), 'Recall': tensor(0.1111)}
+        >>> metrics = MetricCollection(MulticlassAccuracy(num_classes=3, average='micro'),
+        ...                            MulticlassPrecision(num_classes=3, average='macro'),
+        ...                            MulticlassRecall(num_classes=3, average='macro'))
+        >>> metrics(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        {'MulticlassAccuracy': tensor(0.1250),
+         'MulticlassPrecision': tensor(0.0667),
+         'MulticlassRecall': tensor(0.1111)}
 
     Example (input as dict):
-        >>> metrics = MetricCollection({'micro_recall': Recall(num_classes=3, average='micro'),
-        ...                             'macro_recall': Recall(num_classes=3, average='macro')})
+        >>> metrics = MetricCollection({'micro_recall': MulticlassRecall(num_classes=3, average='micro'),
+        ...                             'macro_recall': MulticlassRecall(num_classes=3, average='macro')})
         >>> same_metric = metrics.clone()
         >>> pprint(metrics(preds, target))
         {'macro_recall': tensor(0.1111), 'micro_recall': tensor(0.1250)}
@@ -109,33 +115,33 @@ class MetricCollection(ModuleDict):
 
     Example (specification of compute groups):
         >>> metrics = MetricCollection(
-        ...     Recall(num_classes=3, average='macro'),
-        ...     Precision(num_classes=3, average='macro'),
+        ...     MulticlassRecall(num_classes=3, average='macro'),
+        ...     MulticlassPrecision(num_classes=3, average='macro'),
         ...     MeanSquaredError(),
-        ...     compute_groups=[['Recall', 'Precision'], ['MeanSquaredError']]
+        ...     compute_groups=[['MulticlassRecall', 'MulticlassPrecision'], ['MeanSquaredError']]
         ... )
         >>> metrics.update(preds, target)
         >>> pprint(metrics.compute())
-        {'MeanSquaredError': tensor(2.3750), 'Precision': tensor(0.0667), 'Recall': tensor(0.1111)}
+        {'MeanSquaredError': tensor(2.3750), 'MulticlassPrecision': tensor(0.0667), 'MulticlassRecall': tensor(0.1111)}
         >>> pprint(metrics.compute_groups)
-        {0: ['Recall', 'Precision'], 1: ['MeanSquaredError']}
+        {0: ['MulticlassRecall', 'MulticlassPrecision'], 1: ['MeanSquaredError']}
 
     Example (nested metric collections):
         >>> metrics = MetricCollection([
         ...     MetricCollection([
-        ...         Accuracy(num_classes=3, average='macro'),
-        ...         Precision(num_classes=3, average='macro')
+        ...         MulticlassAccuracy(num_classes=3, average='macro'),
+        ...         MulticlassPrecision(num_classes=3, average='macro')
         ...     ], postfix='_macro'),
         ...     MetricCollection([
-        ...         Accuracy(num_classes=3, average='micro'),
-        ...         Precision(num_classes=3, average='micro')
+        ...         MulticlassAccuracy(num_classes=3, average='micro'),
+        ...         MulticlassPrecision(num_classes=3, average='micro')
         ...     ], postfix='_micro'),
         ... ], prefix='valmetrics/')
         >>> pprint(metrics(preds, target))  # doctest: +NORMALIZE_WHITESPACE
-        {'valmetrics/Accuracy_macro': tensor(0.1111),
-        'valmetrics/Accuracy_micro': tensor(0.1250),
-        'valmetrics/Precision_macro': tensor(0.0667),
-        'valmetrics/Precision_micro': tensor(0.1250)}
+        {'valmetrics/MulticlassAccuracy_macro': tensor(0.1111),
+         'valmetrics/MulticlassAccuracy_micro': tensor(0.1250),
+         'valmetrics/MulticlassPrecision_macro': tensor(0.0667),
+         'valmetrics/MulticlassPrecision_micro': tensor(0.1250)}
     """
 
     _groups: Dict[int, List[str]]
@@ -411,6 +417,7 @@ class MetricCollection(ModuleDict):
 
     def keys(self, keep_base: bool = False) -> Iterable[Hashable]:
         r"""Return an iterable of the ModuleDict key.
+
         Args:
             keep_base: Whether to add prefix/postfix on the items collection.
         """
