@@ -197,11 +197,9 @@ def _fix_empty_tensors(boxes: Tensor) -> Tensor:
 
 
 class MeanAveragePrecision(Metric):
-    r"""
-    Computes the `Mean-Average-Precision (mAP) and Mean-Average-Recall (mAR)
-    <https://jonathan-hui.medium.com/map-mean-average-precision-for-object-detection-45c121a31173>`_
-    for object detection predictions.
-    Optionally, the mAP and mAR values can be calculated per class.
+    r"""`Computes the `Mean-Average-Precision (mAP) and Mean-Average-Recall (mAR) <https://jonathan-
+    hui.medium.com/map-mean-average-precision-for-object-detection-45c121a31173>`_ for object detection
+    predictions. Optionally, the mAP and mAR values can be calculated per class.
 
     Predicted boxes and targets have to be in Pascal VOC format
     (xmin-top left, ymin-top left, xmax-bottom right, ymax-bottom right).
@@ -303,7 +301,7 @@ class MeanAveragePrecision(Metric):
         max_detection_thresholds: Optional[List[int]] = None,
         class_metrics: bool = False,
         **kwargs: Any,
-    ) -> None:  # type: ignore
+    ) -> None:
         super().__init__(**kwargs)
 
         if not _TORCHVISION_GREATER_EQUAL_0_8:
@@ -502,7 +500,7 @@ class MeanAveragePrecision(Metric):
         return {
             "dtMatches": torch.zeros((nb_iou_thrs, nb_det), dtype=torch.bool, device=self.device),
             "gtMatches": torch.zeros((nb_iou_thrs, nb_gt), dtype=torch.bool, device=self.device),
-            "dtScores": torch.zeros(nb_det, dtype=torch.bool, device=self.device),
+            "dtScores": torch.zeros(nb_det, dtype=torch.float32, device=self.device),
             "gtIgnore": gt_ignore,
             "dtIgnore": det_ignore,
         }
