@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import warnings
 from typing import List, Optional, Tuple, Union
 
 import torch
@@ -34,8 +33,6 @@ from torchmetrics.functional.classification.precision_recall_curve import (
     _multilabel_precision_recall_curve_format,
     _multilabel_precision_recall_curve_tensor_validation,
     _multilabel_precision_recall_curve_update,
-    _precision_recall_curve_compute,
-    _precision_recall_curve_update,
 )
 from torchmetrics.utilities.compute import _safe_divide
 from torchmetrics.utilities.data import _bincount
@@ -88,8 +85,7 @@ def binary_average_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the average precision (AP) score for binary tasks. The AP score summarizes a precision-recall curve
+    r"""Computes the average precision (AP) score for binary tasks. The AP score summarizes a precision-recall curve
     as an weighted mean of precisions at each threshold, with the difference in recall from the previous threshold
     as weight:
 
@@ -189,10 +185,9 @@ def multiclass_average_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the average precision (AP) score for binary tasks. The AP score summarizes a precision-recall curve
-    as an weighted mean of precisions at each threshold, with the difference in recall from the previous threshold
-    as weight:
+    r"""Computes the average precision (AP) score for multiclass tasks. The AP score summarizes a precision-recall
+    curve as an weighted mean of precisions at each threshold, with the difference in recall from the previous
+    threshold as weight:
 
     .. math::
         AP = \sum{n} (R_n - R_{n-1}) P_n
@@ -259,7 +254,6 @@ def multiclass_average_precision(
         tensor(0.5000)
         >>> multiclass_average_precision(preds, target, num_classes=5, average=None, thresholds=5)
         tensor([1.0000, 1.0000, 0.2500, 0.2500, -0.0000])
-
     """
     if validate_args:
         _multiclass_average_precision_arg_validation(num_classes, average, thresholds, ignore_index)
@@ -320,10 +314,9 @@ def multilabel_average_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the average precision (AP) score for binary tasks. The AP score summarizes a precision-recall curve
-    as an weighted mean of precisions at each threshold, with the difference in recall from the previous threshold
-    as weight:
+    r"""Computes the average precision (AP) score for multilabel tasks. The AP score summarizes a precision-recall
+    curve as an weighted mean of precisions at each threshold, with the difference in recall from the previous
+    threshold as weight:
 
     .. math::
         AP = \sum{n} (R_n - R_{n-1}) P_n
@@ -405,240 +398,56 @@ def multilabel_average_precision(
     return _multilabel_average_precision_compute(state, num_labels, average, thresholds, ignore_index)
 
 
-def _average_precision_update(
-    preds: Tensor,
-    target: Tensor,
-    num_classes: Optional[int] = None,
-    pos_label: Optional[int] = None,
-    average: Optional[str] = "macro",
-) -> Tuple[Tensor, Tensor, int, Optional[int]]:
-    """Format the predictions and target based on the ``num_classes``, ``pos_label`` and ``average`` parameter.
-
-    Args:
-        preds: predictions from model (logits or probabilities)
-        target: ground truth values
-        num_classes: integer with number of classes.
-        pos_label: integer determining the positive class. Default is ``None`` which for binary problem is translated
-            to 1. For multiclass problems this argument should not be set as we iteratively change it in the
-            range ``[0, num_classes-1]``
-        average: reduction method for multi-class or multi-label problems
-    """
-    preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target, num_classes, pos_label)
-    if average == "micro" and preds.ndim != target.ndim:
-        raise ValueError("Cannot use `micro` average with multi-class input")
-
-    return preds, target, num_classes, pos_label
-
-
-def _average_precision_compute(
-    preds: Tensor,
-    target: Tensor,
-    num_classes: int,
-    pos_label: Optional[int] = None,
-    average: Optional[str] = "macro",
-) -> Union[List[Tensor], Tensor]:
-    """Computes the average precision score.
-
-    Args:
-        preds: predictions from model (logits or probabilities)
-        target: ground truth values
-        num_classes: integer with number of classes.
-        pos_label: integer determining the positive class. Default is ``None`` which for binary problem is translated
-            to 1. For multiclass problems his argument should not be set as we iteratively change it in the
-            range ``[0, num_classes-1]``
-        average: reduction method for multi-class or multi-label problems
-
-    Example:
-        >>> # binary case
-        >>> preds = torch.tensor([0, 1, 2, 3])
-        >>> target = torch.tensor([0, 1, 1, 1])
-        >>> pos_label = 1
-        >>> preds, target, num_classes, pos_label = _average_precision_update(preds, target, pos_label=pos_label)
-        >>> _average_precision_compute(preds, target, num_classes, pos_label)
-        tensor(1.)
-
-        >>> # multiclass case
-        >>> preds = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
-        ...                      [0.05, 0.75, 0.05, 0.05, 0.05],
-        ...                      [0.05, 0.05, 0.75, 0.05, 0.05],
-        ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
-        >>> target = torch.tensor([0, 1, 3, 2])
-        >>> num_classes = 5
-        >>> preds, target, num_classes, pos_label = _average_precision_update(preds, target, num_classes)
-        >>> _average_precision_compute(preds, target, num_classes, average=None)
-        [tensor(1.), tensor(1.), tensor(0.2500), tensor(0.2500), tensor(nan)]
-    """
-
-    if average == "micro" and preds.ndim == target.ndim:
-        preds = preds.flatten()
-        target = target.flatten()
-        num_classes = 1
-
-    precision, recall, _ = _precision_recall_curve_compute(preds, target, num_classes, pos_label)
-    if average == "weighted":
-        if preds.ndim == target.ndim and target.ndim > 1:
-            weights = target.sum(dim=0).float()
-        else:
-            weights = _bincount(target, minlength=max(num_classes, 2)).float()
-        weights = weights / torch.sum(weights)
-    else:
-        weights = None
-    return _average_precision_compute_with_precision_recall(precision, recall, num_classes, average, weights)
-
-
-def _average_precision_compute_with_precision_recall(
-    precision: Tensor,
-    recall: Tensor,
-    num_classes: int,
-    average: Optional[str] = "macro",
-    weights: Optional[Tensor] = None,
-) -> Union[List[Tensor], Tensor]:
-    """Computes the average precision score from precision and recall.
-
-    Args:
-        precision: precision values
-        recall: recall values
-        num_classes: integer with number of classes. Not nessesary to provide
-            for binary problems.
-        average: reduction method for multi-class or multi-label problems
-        weights: weights to use when average='weighted'
-
-    Example:
-        >>> # binary case
-        >>> preds = torch.tensor([0, 1, 2, 3])
-        >>> target = torch.tensor([0, 1, 1, 1])
-        >>> pos_label = 1
-        >>> preds, target, num_classes, pos_label = _average_precision_update(preds, target, pos_label=pos_label)
-        >>> precision, recall, _ = _precision_recall_curve_compute(preds, target, num_classes, pos_label)
-        >>> _average_precision_compute_with_precision_recall(precision, recall, num_classes, average=None)
-        tensor(1.)
-
-        >>> # multiclass case
-        >>> preds = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
-        ...                      [0.05, 0.75, 0.05, 0.05, 0.05],
-        ...                      [0.05, 0.05, 0.75, 0.05, 0.05],
-        ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
-        >>> target = torch.tensor([0, 1, 3, 2])
-        >>> num_classes = 5
-        >>> preds, target, num_classes, pos_label = _average_precision_update(preds, target, num_classes)
-        >>> precision, recall, _ = _precision_recall_curve_compute(preds, target, num_classes)
-        >>> _average_precision_compute_with_precision_recall(precision, recall, num_classes, average=None)
-        [tensor(1.), tensor(1.), tensor(0.2500), tensor(0.2500), tensor(nan)]
-    """
-
-    # Return the step function integral
-    # The following works because the last entry of precision is
-    # guaranteed to be 1, as returned by precision_recall_curve
-    if num_classes == 1:
-        return -torch.sum((recall[1:] - recall[:-1]) * precision[:-1])
-
-    res = []
-    for p, r in zip(precision, recall):
-        res.append(-torch.sum((r[1:] - r[:-1]) * p[:-1]))
-
-    # Reduce
-    if average in ("macro", "weighted"):
-        res = torch.stack(res)
-        if torch.isnan(res).any():
-            warnings.warn(
-                "Average precision score for one or more classes was `nan`. Ignoring these classes in average",
-                UserWarning,
-            )
-        if average == "macro":
-            return res[~torch.isnan(res)].mean()
-        weights = torch.ones_like(res) if weights is None else weights
-        return (res * weights)[~torch.isnan(res)].sum()
-    if average is None or average == "none":
-        return res
-    allowed_average = ("micro", "macro", "weighted", "none", None)
-    raise ValueError(f"Expected argument `average` to be one of {allowed_average}" f" but got {average}")
-
-
 def average_precision(
     preds: Tensor,
     target: Tensor,
-    num_classes: Optional[int] = None,
-    pos_label: Optional[int] = None,
-    average: Optional[Literal["macro", "weighted", "none"]] = "macro",
-    task: Optional[Literal["binary", "multiclass", "multilabel"]] = None,
+    task: Literal["binary", "multiclass", "multilabel"],
     thresholds: Optional[Union[int, List[float], Tensor]] = None,
+    num_classes: Optional[int] = None,
     num_labels: Optional[int] = None,
+    average: Optional[Literal["macro", "weighted", "none"]] = "macro",
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Union[List[Tensor], Tensor]:
-    r"""
-    .. note::
-        From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification
-        metric. Moving forward we recommend using these versions. This base metric will still work as it did
-        prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required
-        and the general order of arguments may change, such that this metric will just function as an single
-        entrypoint to calling the three specialized versions.
+    r"""Computes the average precision (AP) score. The AP score summarizes a precision-recall curve as an weighted
+    mean of precisions at each threshold, with the difference in recall from the previous threshold as weight:
 
-    Computes the average precision score.
+    .. math::
+        AP = \sum{n} (R_n - R_{n-1}) P_n
 
-    Args:
-        preds: predictions from model (logits or probabilities)
-        target: ground truth values
-        num_classes: integer with number of classes. Not nessesary to provide
-            for binary problems.
-        pos_label: integer determining the positive class. Default is ``None`` which for binary problem is translated
-            to 1. For multiclass problems his argument should not be set as we iteratively change it in the
-            range ``[0, num_classes-1]``
-        average:
-            defines the reduction that is applied in the case of multiclass and multilabel input.
-            Should be one of the following:
+    where :math:`P_n, R_n` is the respective precision and recall at threshold index :math:`n`. This value is
+    equivalent to the area under the precision-recall curve (AUPRC).
 
-            - ``'macro'`` [default]: Calculate the metric for each class separately, and average the
-              metrics across classes (with equal weights for each class).
-            - ``'weighted'``: Calculate the metric for each class separately, and average the
-              metrics across classes, weighting each class by its support.
-            - ``'none'`` or ``None``: Calculate the metric for each class separately, and return
-              the metric for every class.
+    This function is a simple wrapper to get the task specific versions of this metric, which is done by setting the
+    ``task`` argument to either ``'binary'``, ``'multiclass'`` or ``multilabel``. See the documentation of
+    :func:`binary_average_precision`, :func:`multiclass_average_precision` and :func:`multilabel_average_precision`
+    for the specific details of each argument influence and examples.
 
-    Returns:
-        tensor with average precision. If multiclass will return list
-        of such tensors, one for each class
-
-    Example (binary case):
+    Legacy Example:
         >>> from torchmetrics.functional import average_precision
-        >>> pred = torch.tensor([0, 1, 2, 3])
+        >>> pred = torch.tensor([0.0, 1.0, 2.0, 3.0])
         >>> target = torch.tensor([0, 1, 1, 1])
-        >>> average_precision(pred, target, pos_label=1)
+        >>> average_precision(pred, target, task="binary")
         tensor(1.)
 
-    Example (multiclass case):
         >>> pred = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
         ...                      [0.05, 0.75, 0.05, 0.05, 0.05],
         ...                      [0.05, 0.05, 0.75, 0.05, 0.05],
         ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
         >>> target = torch.tensor([0, 1, 3, 2])
-        >>> average_precision(pred, target, num_classes=5, average=None)
-        [tensor(1.), tensor(1.), tensor(0.2500), tensor(0.2500), tensor(nan)]
+        >>> average_precision(pred, target, task="multiclass", num_classes=5, average=None)
+        tensor([1.0000, 1.0000, 0.2500, 0.2500,    nan])
     """
-    if task is not None:
-        if task == "binary":
-            return binary_average_precision(preds, target, thresholds, ignore_index, validate_args)
-        if task == "multiclass":
-            assert isinstance(num_classes, int)
-            return multiclass_average_precision(
-                preds, target, num_classes, average, thresholds, ignore_index, validate_args
-            )
-        if task == "multilabel":
-            assert isinstance(num_labels, int)
-            return multilabel_average_precision(
-                preds, target, num_labels, average, thresholds, ignore_index, validate_args
-            )
-        raise ValueError(
-            f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
+    if task == "binary":
+        return binary_average_precision(preds, target, thresholds, ignore_index, validate_args)
+    if task == "multiclass":
+        assert isinstance(num_classes, int)
+        return multiclass_average_precision(
+            preds, target, num_classes, average, thresholds, ignore_index, validate_args
         )
-    else:
-        rank_zero_warn(
-            "From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification"
-            " metric. Moving forward we recommend using these versions. This base metric will still work as it did"
-            " prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required"
-            " and the general order of arguments may change, such that this metric will just function as an single"
-            " entrypoint to calling the three specialized versions.",
-            DeprecationWarning,
-        )
-    preds, target, num_classes, pos_label = _average_precision_update(preds, target, num_classes, pos_label, average)
-    return _average_precision_compute(preds, target, num_classes, pos_label, average)
+    if task == "multilabel":
+        assert isinstance(num_labels, int)
+        return multilabel_average_precision(preds, target, num_labels, average, thresholds, ignore_index, validate_args)
+    raise ValueError(
+        f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
+    )
