@@ -17,9 +17,8 @@ import torch
 from torch import Tensor
 from typing_extensions import Literal
 
-from torchmetrics.utilities.checks import _check_same_shape, _input_format_classification
-from torchmetrics.utilities.data import _bincount, _movedim
-from torchmetrics.utilities.enums import DataType
+from torchmetrics.utilities.checks import _check_same_shape
+from torchmetrics.utilities.data import _bincount
 from torchmetrics.utilities.prints import rank_zero_warn
 
 
@@ -166,8 +165,7 @@ def binary_confusion_matrix(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the `confusion matrix`_ for binary tasks.
+    r"""Computes the `confusion matrix`_ for binary tasks.
 
     Accepts the following input tensors:
 
@@ -315,7 +313,7 @@ def _multiclass_confusion_matrix_format(
     if convert_to_labels:
         preds = preds.flatten()
     else:
-        preds = _movedim(preds, 1, -1).reshape(-1, preds.shape[1])
+        preds = torch.movedim(preds, 1, -1).reshape(-1, preds.shape[1])
     target = target.flatten()
 
     if ignore_index is not None:
@@ -351,8 +349,7 @@ def multiclass_confusion_matrix(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the `confusion matrix`_ for multiclass tasks.
+    r"""Computes the `confusion matrix`_ for multiclass tasks.
 
     Accepts the following input tensors:
 
@@ -496,8 +493,8 @@ def _multilabel_confusion_matrix_format(
             preds = preds.sigmoid()
         if should_threshold:
             preds = preds > threshold
-    preds = _movedim(preds, 1, -1).reshape(-1, num_labels)
-    target = _movedim(target, 1, -1).reshape(-1, num_labels)
+    preds = torch.movedim(preds, 1, -1).reshape(-1, num_labels)
+    target = torch.movedim(target, 1, -1).reshape(-1, num_labels)
 
     if ignore_index is not None:
         preds = preds.clone()
@@ -538,8 +535,7 @@ def multilabel_confusion_matrix(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    Computes the `confusion matrix`_ for multilabel tasks.
+    r"""Computes the `confusion matrix`_ for multilabel tasks.
 
     Accepts the following input tensors:
 
@@ -595,200 +591,57 @@ def multilabel_confusion_matrix(
     return _multilabel_confusion_matrix_compute(confmat, normalize)
 
 
-def _confusion_matrix_update(
-    preds: Tensor, target: Tensor, num_classes: int, threshold: float = 0.5, multilabel: bool = False
-) -> Tensor:
-    """Updates and returns confusion matrix (without any normalization) based on the mode of the input.
-
-    Args:
-        preds: Predicted tensor
-        target: Ground truth tensor
-        threshold: Threshold for transforming probability or logit predictions to binary (0,1) predictions, in the
-            case of binary or multi-label inputs. Default value of 0.5 corresponds to input being probabilities.
-        multilabel: determines if data is multilabel or not.
-    """
-
-    preds, target, mode = _input_format_classification(preds, target, threshold)
-    if mode not in (DataType.BINARY, DataType.MULTILABEL):
-        preds = preds.argmax(dim=1)
-        target = target.argmax(dim=1)
-    if multilabel:
-        unique_mapping = ((2 * target + preds) + 4 * torch.arange(num_classes, device=preds.device)).flatten()
-        minlength = 4 * num_classes
-    else:
-        unique_mapping = (target.view(-1) * num_classes + preds.view(-1)).to(torch.long)
-        minlength = num_classes**2
-
-    bins = _bincount(unique_mapping, minlength=minlength)
-    if multilabel:
-        confmat = bins.reshape(num_classes, 2, 2)
-    else:
-        confmat = bins.reshape(num_classes, num_classes)
-    return confmat
-
-
-def _confusion_matrix_compute(confmat: Tensor, normalize: Optional[str] = None) -> Tensor:
-    """Computes confusion matrix based on the normalization mode.
-
-    Args:
-        confmat: Confusion matrix without normalization
-        normalize: Normalization mode for confusion matrix. Choose from:
-
-            - ``None`` or ``'none'``: no normalization (default)
-            - ``'true'``: normalization over the targets (most commonly used)
-            - ``'pred'``: normalization over the predictions
-            - ``'all'``: normalization over the whole matrix
-
-    Example:
-        >>> # binary case
-        >>> target = torch.tensor([1, 1, 0, 0])
-        >>> preds = torch.tensor([0, 1, 0, 0])
-        >>> confmat = _confusion_matrix_update(preds, target, num_classes=2)
-        >>> _confusion_matrix_compute(confmat)
-        tensor([[2, 0],
-                [1, 1]])
-
-        >>> # multiclass case
-        >>> target = torch.tensor([2, 1, 0, 0])
-        >>> preds = torch.tensor([2, 1, 0, 1])
-        >>> confmat = _confusion_matrix_update(preds, target, num_classes=3)
-        >>> _confusion_matrix_compute(confmat)
-        tensor([[1, 1, 0],
-                [0, 1, 0],
-                [0, 0, 1]])
-
-        >>> # multilabel case
-        >>> target = torch.tensor([[0, 1, 0], [1, 0, 1]])
-        >>> preds = torch.tensor([[0, 0, 1], [1, 0, 1]])
-        >>> confmat = _confusion_matrix_update(preds, target, num_classes=3, multilabel=True)
-        >>> _confusion_matrix_compute(confmat)
-        tensor([[[1, 0], [0, 1]],
-                [[1, 0], [1, 0]],
-                [[0, 1], [0, 1]]])
-    """
-
-    allowed_normalize = ("true", "pred", "all", "none", None)
-    if normalize not in allowed_normalize:
-        raise ValueError(f"Argument average needs to one of the following: {allowed_normalize}")
-    if normalize is not None and normalize != "none":
-        confmat = confmat.float() if not confmat.is_floating_point() else confmat
-        if normalize == "true":
-            confmat = confmat / confmat.sum(axis=1, keepdim=True)
-        elif normalize == "pred":
-            confmat = confmat / confmat.sum(axis=0, keepdim=True)
-        elif normalize == "all":
-            confmat = confmat / confmat.sum()
-
-        nan_elements = confmat[torch.isnan(confmat)].nelement()
-        if nan_elements != 0:
-            confmat[torch.isnan(confmat)] = 0
-            rank_zero_warn(f"{nan_elements} nan values found in confusion matrix have been replaced with zeros.")
-    return confmat
-
-
 def confusion_matrix(
     preds: Tensor,
     target: Tensor,
-    num_classes: int,
-    normalize: Optional[Literal["true", "pred", "all", "none"]] = None,
+    task: Literal["binary", "multiclass", "multilabel"],
     threshold: float = 0.5,
-    multilabel: bool = False,
-    task: Optional[Literal["binary", "multiclass", "multilabel"]] = None,
+    num_classes: Optional[int] = None,
     num_labels: Optional[int] = None,
+    normalize: Optional[Literal["true", "pred", "all", "none"]] = None,
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    .. note::
-        From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification
-        metric. Moving forward we recommend using these versions. This base metric will still work as it did
-        prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required
-        and the general order of arguments may change, such that this metric will just function as an single
-        entrypoint to calling the three specialized versions.
+    r"""Computes the `confusion matrix`_.
 
+    This function is a simple wrapper to get the task specific versions of this metric, which is done by setting the
+    ``task`` argument to either ``'binary'``, ``'multiclass'`` or ``multilabel``. See the documentation of
+    :func:`binary_confusion_matrix`, :func:`multiclass_confusion_matrix` and :func:`multilabel_confusion_matrix` for
+    the specific details of each argument influence and examples.
 
-    Computes the `confusion matrix`_.  Works with binary,
-    multiclass, and multilabel data.  Accepts probabilities or logits from a model output or integer class
-    values in prediction. Works with multi-dimensional preds and target, but it should be noted that
-    additional dimensions will be flattened.
-
-    If preds and target are the same shape and preds is a float tensor, we use the ``self.threshold`` argument
-    to convert into integer labels. This is the case for binary and multi-label probabilities or logits.
-
-    If preds has an extra dimension as in the case of multi-class scores we perform an argmax on ``dim=1``.
-
-    If working with multilabel data, setting the ``is_multilabel`` argument to ``True`` will make sure that a
-    `confusion matrix gets calculated per label`_.
-
-    Args:
-        preds: (float or long tensor), Either a ``(N, ...)`` tensor with labels or
-            ``(N, C, ...)`` where C is the number of classes, tensor with labels/logits/probabilities
-        target: ``target`` (long tensor), tensor with shape ``(N, ...)`` with ground true labels
-        num_classes: Number of classes in the dataset.
-        normalize: Normalization mode for confusion matrix. Choose from:
-
-            - ``None`` or ``'none'``: no normalization (default)
-            - ``'true'``: normalization over the targets (most commonly used)
-            - ``'pred'``: normalization over the predictions
-            - ``'all'``: normalization over the whole matrix
-
-        threshold:
-            Threshold for transforming probability or logit predictions to binary (0,1) predictions, in the case
-            of binary or multi-label inputs. Default value of 0.5 corresponds to input being probabilities.
-
-        multilabel:
-            determines if data is multilabel or not.
-
-    Example (binary data):
+    Legacy Example:
         >>> from torchmetrics import ConfusionMatrix
         >>> target = torch.tensor([1, 1, 0, 0])
         >>> preds = torch.tensor([0, 1, 0, 0])
-        >>> confmat = ConfusionMatrix(num_classes=2)
+        >>> confmat = ConfusionMatrix(task="binary")
         >>> confmat(preds, target)
         tensor([[2, 0],
                 [1, 1]])
 
-    Example (multiclass data):
         >>> target = torch.tensor([2, 1, 0, 0])
         >>> preds = torch.tensor([2, 1, 0, 1])
-        >>> confmat = ConfusionMatrix(num_classes=3)
+        >>> confmat = ConfusionMatrix(task="multiclass", num_classes=3)
         >>> confmat(preds, target)
         tensor([[1, 1, 0],
                 [0, 1, 0],
                 [0, 0, 1]])
 
-    Example (multilabel data):
         >>> target = torch.tensor([[0, 1, 0], [1, 0, 1]])
         >>> preds = torch.tensor([[0, 0, 1], [1, 0, 1]])
-        >>> confmat = ConfusionMatrix(num_classes=3, multilabel=True)
+        >>> confmat = ConfusionMatrix(task="multilabel", num_labels=3)
         >>> confmat(preds, target)
         tensor([[[1, 0], [0, 1]],
                 [[1, 0], [1, 0]],
                 [[0, 1], [0, 1]]])
-
     """
-    if task is not None:
-        if task == "binary":
-            return binary_confusion_matrix(preds, target, threshold, normalize, ignore_index, validate_args)
-        if task == "multiclass":
-            assert isinstance(num_classes, int)
-            return multiclass_confusion_matrix(preds, target, num_classes, normalize, ignore_index, validate_args)
-        if task == "multilabel":
-            assert isinstance(num_labels, int)
-            return multilabel_confusion_matrix(
-                preds, target, num_labels, threshold, normalize, ignore_index, validate_args
-            )
-        raise ValueError(
-            f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
-        )
-    else:
-        rank_zero_warn(
-            "From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification"
-            " metric. Moving forward we recommend using these versions. This base metric will still work as it did"
-            " prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required"
-            " and the general order of arguments may change, such that this metric will just function as an single"
-            " entrypoint to calling the three specialized versions.",
-            DeprecationWarning,
-        )
-    confmat = _confusion_matrix_update(preds, target, num_classes, threshold, multilabel)
-    return _confusion_matrix_compute(confmat, normalize)
+    if task == "binary":
+        return binary_confusion_matrix(preds, target, threshold, normalize, ignore_index, validate_args)
+    if task == "multiclass":
+        assert isinstance(num_classes, int)
+        return multiclass_confusion_matrix(preds, target, num_classes, normalize, ignore_index, validate_args)
+    if task == "multilabel":
+        assert isinstance(num_labels, int)
+        return multilabel_confusion_matrix(preds, target, num_labels, threshold, normalize, ignore_index, validate_args)
+    raise ValueError(
+        f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
+    )
