@@ -22,7 +22,6 @@ from torchmetrics.functional.classification.confusion_matrix import (
     _binary_confusion_matrix_format,
     _binary_confusion_matrix_tensor_validation,
     _binary_confusion_matrix_update,
-    _confusion_matrix_update,
     _multiclass_confusion_matrix_arg_validation,
     _multiclass_confusion_matrix_format,
     _multiclass_confusion_matrix_tensor_validation,
@@ -33,7 +32,6 @@ from torchmetrics.functional.classification.confusion_matrix import (
     _multilabel_confusion_matrix_update,
 )
 from torchmetrics.utilities.compute import _safe_divide
-from torchmetrics.utilities.prints import rank_zero_warn
 
 
 def _jaccard_index_reduce(
@@ -91,10 +89,10 @@ def binary_jaccard_index(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""Calculates the Jaccard index for binary tasks. The `Jaccard index`_ (also known as
-    the intersetion over union or jaccard similarity coefficient) is an statistic that can be
-    used to determine the similarity and diversity of a sample set. It is defined as the size
-    of the intersection divided by the union of the sample sets:
+    r"""Calculates the Jaccard index for binary tasks. The `Jaccard index`_ (also known as the intersetion over
+    union or jaccard similarity coefficient) is an statistic that can be used to determine the similarity and
+    diversity of a sample set. It is defined as the size of the intersection divided by the union of the sample
+    sets:
 
     .. math:: J(A,B) = \frac{|A\cap B|}{|A\cup B|}
 
@@ -163,10 +161,10 @@ def multiclass_jaccard_index(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""Calculates the Jaccard index for multiclass tasks. The `Jaccard index`_ (also known as
-    the intersetion over union or jaccard similarity coefficient) is an statistic that can be
-    used to determine the similarity and diversity of a sample set. It is defined as the size
-    of the intersection divided by the union of the sample sets:
+    r"""Calculates the Jaccard index for multiclass tasks. The `Jaccard index`_ (also known as the intersetion over
+    union or jaccard similarity coefficient) is an statistic that can be used to determine the similarity and
+    diversity of a sample set. It is defined as the size of the intersection divided by the union of the sample
+    sets:
 
     .. math:: J(A,B) = \frac{|A\cap B|}{|A\cup B|}
 
@@ -243,10 +241,10 @@ def multilabel_jaccard_index(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""Calculates the Jaccard index for multilabel tasks. The `Jaccard index`_ (also known as
-    the intersetion over union or jaccard similarity coefficient) is an statistic that can be
-    used to determine the similarity and diversity of a sample set. It is defined as the size
-    of the intersection divided by the union of the sample sets:
+    r"""Calculates the Jaccard index for multilabel tasks. The `Jaccard index`_ (also known as the intersetion over
+    union or jaccard similarity coefficient) is an statistic that can be used to determine the similarity and
+    diversity of a sample set. It is defined as the size of the intersection divided by the union of the sample
+    sets:
 
     .. math:: J(A,B) = \frac{|A\cap B|}{|A\cup B|}
 
@@ -289,7 +287,6 @@ def multilabel_jaccard_index(
         >>> preds = torch.tensor([[0.11, 0.22, 0.84], [0.73, 0.33, 0.92]])
         >>> multilabel_jaccard_index(preds, target, num_labels=3)
         tensor(0.5000)
-
     """
     if validate_args:
         _multilabel_jaccard_index_arg_validation(num_labels, threshold, ignore_index)
@@ -299,177 +296,44 @@ def multilabel_jaccard_index(
     return _jaccard_index_reduce(confmat, average=average)
 
 
-def _jaccard_from_confmat(
-    confmat: Tensor,
-    num_classes: int,
-    average: Optional[str] = "macro",
-    ignore_index: Optional[int] = None,
-    absent_score: float = 0.0,
-) -> Tensor:
-    """Computes the intersection over union from confusion matrix.
-
-    Args:
-        confmat: Confusion matrix without normalization
-        num_classes: Number of classes for a given prediction and target tensor
-        average:
-            Defines the reduction that is applied. Should be one of the following:
-
-            - ``'macro'`` [default]: Calculate the metric for each class separately, and average the
-              metrics across classes (with equal weights for each class).
-            - ``'micro'``: Calculate the metric globally, across all samples and classes.
-            - ``'weighted'``: Calculate the metric for each class separately, and average the
-              metrics across classes, weighting each class by its support (``tp + fn``).
-            - ``'none'`` or ``None``: Calculate the metric for each class separately, and return
-              the metric for every class. Note that if a given class doesn't occur in the
-              `preds` or `target`, the value for the class will be ``nan``.
-
-        ignore_index: optional int specifying a target class to ignore. If given, this class index does not contribute
-            to the returned score, regardless of reduction method.
-        absent_score: score to use for an individual class, if no instances of the class index were present in `pred`
-            AND no instances of the class index were present in `target`.
-    """
-    allowed_average = ["micro", "macro", "weighted", "none", None]
-    if average not in allowed_average:
-        raise ValueError(f"The `average` has to be one of {allowed_average}, got {average}.")
-
-    # Remove the ignored class index from the scores.
-    if ignore_index is not None and 0 <= ignore_index < num_classes:
-        confmat[ignore_index] = 0.0
-
-    if average == "none" or average is None:
-        intersection = torch.diag(confmat)
-        union = confmat.sum(0) + confmat.sum(1) - intersection
-
-        # If this class is absent in both target AND pred (union == 0), then use the absent_score for this class.
-        scores = intersection.float() / union.float()
-        scores = scores.where(union != 0, torch.tensor(absent_score, dtype=scores.dtype, device=scores.device))
-
-        if ignore_index is not None and 0 <= ignore_index < num_classes:
-            scores = torch.cat(
-                [
-                    scores[:ignore_index],
-                    scores[ignore_index + 1 :],
-                ]
-            )
-        return scores
-
-    if average == "macro":
-        scores = _jaccard_from_confmat(
-            confmat, num_classes, average="none", ignore_index=ignore_index, absent_score=absent_score
-        )
-        return torch.mean(scores)
-
-    if average == "micro":
-        intersection = torch.sum(torch.diag(confmat))
-        union = torch.sum(torch.sum(confmat, dim=1) + torch.sum(confmat, dim=0) - torch.diag(confmat))
-        return intersection.float() / union.float()
-
-    weights = torch.sum(confmat, dim=1).float() / torch.sum(confmat).float()
-    scores = _jaccard_from_confmat(
-        confmat, num_classes, average="none", ignore_index=ignore_index, absent_score=absent_score
-    )
-    return torch.sum(weights * scores)
-
-
 def jaccard_index(
     preds: Tensor,
     target: Tensor,
-    num_classes: int,
+    task: Literal["binary", "multiclass", "multilabel"],
+    threshold: float = 0.5,
+    num_classes: Optional[int] = None,
+    num_labels: Optional[int] = None,
     average: Optional[Literal["micro", "macro", "weighted", "none"]] = "macro",
     ignore_index: Optional[int] = None,
-    absent_score: float = 0.0,
-    threshold: float = 0.5,
-    task: Optional[Literal["binary", "multiclass", "multilabel"]] = None,
-    num_labels: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tensor:
-    r"""
-    .. note::
-        From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification
-        metric. Moving forward we recommend using these versions. This base metric will still work as it did
-        prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required
-        and the general order of arguments may change, such that this metric will just function as an single
-        entrypoint to calling the three specialized versions.
-
-    Computes `Jaccard index`_
+    r"""Calculates the Jaccard index. The `Jaccard index`_ (also known as the intersetion over
+    union or jaccard similarity coefficient) is an statistic that can be used to determine the similarity and
+    diversity of a sample set. It is defined as the size of the intersection divided by the union of the sample
+    sets:
 
     .. math:: J(A,B) = \frac{|A\cap B|}{|A\cup B|}
 
-    Where: :math:`A` and :math:`B` are both tensors of the same size,
-    containing integer class values. They may be subject to conversion from
-    input data (see description below).
+    This function is a simple wrapper to get the task specific versions of this metric, which is done by setting the
+    ``task`` argument to either ``'binary'``, ``'multiclass'`` or ``multilabel``. See the documentation of
+    :func:`binary_jaccard_index`, :func:`multiclass_jaccard_index` and :func:`multilabel_jaccard_index` for
+    the specific details of each argument influence and examples.
 
-    Note that it is different from box IoU.
-
-    If preds and target are the same shape and preds is a float tensor, we use the ``self.threshold`` argument
-    to convert into integer labels. This is the case for binary and multi-label probabilities.
-
-    If pred has an extra dimension as in the case of multi-class scores we
-    perform an argmax on ``dim=1``.
-
-    Args:
-        preds: tensor containing predictions from model (probabilities, or labels) with shape ``[N, d1, d2, ...]``
-        target: tensor containing ground truth labels with shape ``[N, d1, d2, ...]``
-        num_classes: Specify the number of classes
-        average:
-            Defines the reduction that is applied. Should be one of the following:
-
-            - ``'macro'`` [default]: Calculate the metric for each class separately, and average the
-              metrics across classes (with equal weights for each class).
-            - ``'micro'``: Calculate the metric globally, across all samples and classes.
-            - ``'weighted'``: Calculate the metric for each class separately, and average the
-              metrics across classes, weighting each class by its support (``tp + fn``).
-            - ``'none'`` or ``None``: Calculate the metric for each class separately, and return
-              the metric for every class. Note that if a given class doesn't occur in the
-              `preds` or `target`, the value for the class will be ``nan``.
-
-        ignore_index: optional int specifying a target class to ignore. If given,
-            this class index does not contribute to the returned score, regardless
-            of reduction method. Has no effect if given an int that is not in the
-            range ``[0, num_classes-1]``, where num_classes is either given or derived
-            from pred and target. By default, no index is ignored, and all classes are used.
-        absent_score: score to use for an individual class, if no instances of
-            the class index were present in ``preds`` AND no instances of the class
-            index were present in ``target``. For example, if we have 3 classes,
-            [0, 0] for ``preds``, and [0, 2] for ``target``, then class 1 would be
-            assigned the `absent_score`.
-        threshold: Threshold value for binary or multi-label probabilities.
-
-    Return:
-        The shape of the returned tensor depends on the ``average`` parameter
-
-        - If ``average in ['micro', 'macro', 'weighted']``, a one-element tensor will be returned
-        - If ``average in ['none', None]``, the shape will be ``(C,)``, where ``C`` stands  for the number
-          of classes
-
-    Example:
-        >>> from torchmetrics.functional import jaccard_index
+    Legacy Example:
         >>> target = torch.randint(0, 2, (10, 25, 25))
         >>> pred = torch.tensor(target)
         >>> pred[2:5, 7:13, 9:15] = 1 - pred[2:5, 7:13, 9:15]
-        >>> jaccard_index(pred, target, num_classes=2)
+        >>> jaccard_index(pred, target, task="multiclass", num_classes=2)
         tensor(0.9660)
     """
-    if task is not None:
-        if task == "binary":
-            return binary_jaccard_index(preds, target, threshold, ignore_index, validate_args)
-        if task == "multiclass":
-            assert isinstance(num_classes, int)
-            return multiclass_jaccard_index(preds, target, num_classes, average, ignore_index, validate_args)
-        if task == "multilabel":
-            assert isinstance(num_labels, int)
-            return multilabel_jaccard_index(preds, target, num_labels, threshold, average, ignore_index, validate_args)
-        raise ValueError(
-            f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
-        )
-    else:
-        rank_zero_warn(
-            "From v0.10 an `'binary_*'`, `'multiclass_*', `'multilabel_*'` version now exist of each classification"
-            " metric. Moving forward we recommend using these versions. This base metric will still work as it did"
-            " prior to v0.10 until v0.11. From v0.11 the `task` argument introduced in this metric will be required"
-            " and the general order of arguments may change, such that this metric will just function as an single"
-            " entrypoint to calling the three specialized versions.",
-            DeprecationWarning,
-        )
-    confmat = _confusion_matrix_update(preds, target, num_classes, threshold)
-    return _jaccard_from_confmat(confmat, num_classes, average, ignore_index, absent_score)
+    if task == "binary":
+        return binary_jaccard_index(preds, target, threshold, ignore_index, validate_args)
+    if task == "multiclass":
+        assert isinstance(num_classes, int)
+        return multiclass_jaccard_index(preds, target, num_classes, average, ignore_index, validate_args)
+    if task == "multilabel":
+        assert isinstance(num_labels, int)
+        return multilabel_jaccard_index(preds, target, num_labels, threshold, average, ignore_index, validate_args)
+    raise ValueError(
+        f"Expected argument `task` to either be `'binary'`, `'multiclass'` or `'multilabel'` but got {task}"
+    )
