@@ -23,7 +23,6 @@ from torch import Tensor
 from torch.nn import Module
 
 from torchmetrics.utilities import apply_to_collection, rank_zero_warn
-from torchmetrics.utilities.checks import is_overridden
 from torchmetrics.utilities.data import (
     _flatten,
     _squeeze_if_scalar,
@@ -69,6 +68,8 @@ class Metric(Module, ABC):
             - process_group: The process group on which the synchronization is called. Default is the world.
             - dist_sync_fn: function that performs the allgather option on the metric state. Default is an
                 custom implementation that calls ``torch.distributed.all_gather`` internally.
+            - distributed_available_fn: function that checks if the distributed backend is available.
+                Defaults to a check of ``torch.distributed.is_available()`` and ``torch.distributed.is_initialized()``.
             - sync_on_compute: If metric state should synchronize when ``compute`` is called. Default is ``True``-
     """
 
@@ -110,6 +111,8 @@ class Metric(Module, ABC):
                 f"Expected keyword argument `dist_sync_fn` to be an callable function but got {self.dist_sync_fn}"
             )
 
+        self.distributed_available_fn = kwargs.pop("distributed_available_fn", jit_distributed_available)
+
         self.sync_on_compute = kwargs.pop("sync_on_compute", True)
         if not isinstance(self.sync_on_compute, bool):
             raise ValueError(
@@ -136,20 +139,6 @@ class Metric(Module, ABC):
         self._is_synced = False
         self._cache: Optional[Dict[str, Union[List[Tensor], Tensor]]] = None
 
-        if self.full_state_update is None and not is_overridden("forward", self, Metric):
-            rank_zero_warn(
-                f"""Torchmetrics v0.9 introduced a new argument class property called `full_state_update` that has
-                not been set for this class ({self.__class__.__name__}). The property determines if `update` by
-                default needs access to the full metric state. If this is not the case, significant speedups can be
-                achieved and we recommend setting this to `False`.
-                We provide an checking function
-                `from torchmetrics.utilities import check_forward_full_state_property`
-                that can be used to check if the `full_state_update=True` (old and potential slower behaviour,
-                default for now) or if `full_state_update=False` can be used safely.
-                """,
-                UserWarning,
-            )
-
     @property
     def _update_called(self) -> bool:
         # Needed for lightning integration
@@ -256,7 +245,7 @@ class Metric(Module, ABC):
         self.update(*args, **kwargs)
         _update_count = self._update_count
 
-        self._to_sync = self.dist_sync_on_step  # type: ignore
+        self._to_sync = self.dist_sync_on_step
         # skip restore cache operation from compute as cache is stored below.
         self._should_unsync = False
         # skip computing on cpu for the batch
@@ -284,6 +273,8 @@ class Metric(Module, ABC):
         self._computed = None
         self._enable_grad = False
         self.compute_on_cpu = _temp_compute_on_cpu
+        if self.compute_on_cpu:
+            self._move_list_states_to_cpu()
 
         return batch_val
 
@@ -321,6 +312,8 @@ class Metric(Module, ABC):
         self._computed = None
         self._enable_grad = False
         self.compute_on_cpu = _temp_compute_on_cpu
+        if self.compute_on_cpu:
+            self._move_list_states_to_cpu()
 
         return batch_val
 
@@ -421,7 +414,7 @@ class Metric(Module, ABC):
         dist_sync_fn: Optional[Callable] = None,
         process_group: Optional[Any] = None,
         should_sync: bool = True,
-        distributed_available: Optional[Callable] = jit_distributed_available,
+        distributed_available: Optional[Callable] = None,
     ) -> None:
         """Sync function for manually controlling when metrics states should be synced across processes.
 
@@ -437,6 +430,9 @@ class Metric(Module, ABC):
         if self._is_synced and should_sync:
             raise TorchMetricsUserError("The Metric has already been synced.")
 
+        if distributed_available is None and self.distributed_available_fn is not None:
+            distributed_available = self.distributed_available_fn
+
         is_distributed = distributed_available() if callable(distributed_available) else None
 
         if not should_sync or not is_distributed:
@@ -481,7 +477,7 @@ class Metric(Module, ABC):
         process_group: Optional[Any] = None,
         should_sync: bool = True,
         should_unsync: bool = True,
-        distributed_available: Optional[Callable] = jit_distributed_available,
+        distributed_available: Optional[Callable] = None,
     ) -> Generator:
         """Context manager to synchronize the states between processes when running in a distributed setting and
         restore the local cache states after yielding.
@@ -527,7 +523,7 @@ class Metric(Module, ABC):
             # if synchronization happened, the current rank accumulated states will be restored to keep
             # accumulation going if ``should_unsync=True``,
             with self.sync_context(
-                dist_sync_fn=self.dist_sync_fn,  # type: ignore
+                dist_sync_fn=self.dist_sync_fn,
                 should_sync=self._to_sync,
                 should_unsync=self._should_unsync,
             ):
@@ -851,7 +847,7 @@ class Metric(Module, ABC):
     def __getnewargs__(self) -> Tuple:
         return (Metric.__str__(self),)
 
-    def __iter__(self) -> Any:
+    def __iter__(self):
         raise NotImplementedError("Metrics does not support iteration.")
 
 
